@@ -8,7 +8,7 @@ use experimental 'smartmatch';
 #use List::Util qw(first);
 use Scalar::Util 'looks_like_number';
 
-our $VERSION = '0.27'; # VERSION
+our $VERSION = '0.28'; # VERSION
 
 my $ATTRS = [qw(
 
@@ -1437,7 +1437,7 @@ Text::ANSITable - Create nice formatted tables using extended ASCII and ANSI col
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -2385,8 +2385,11 @@ For collections of color themes, search for C<Text::ANSITable::ColorTheme::*>
 modules.
 
 Other table-formatting modules: L<Text::Table>, L<Text::SimpleTable>,
-L<Text::ASCIITable> (which I usually used), L<Text::UnicodeTable::Simple>,
-L<Table::Simple> (uses Moose).
+L<Text::ASCIITable>, L<Text::UnicodeTable::Simple>, L<Table::Simple> (uses
+Moose). There are a couple of "extensions" for Text::ASCIITable:
+L<Text::ASCIITable::TW>, L<Text::ASCIITable::Wrap>; Text::ANSITable can be an
+alternative for all those modules since it can already handle wide-characters,
+multiline text in cells.
 
 Modules used: L<Text::ANSI::Util>, L<Color::ANSI::Util>.
 
